==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/PrstGeomShapeCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class PrstGeomShapeCollection (  CollectionBase[XlsPrstGeomShape], IPrstGeomShapes) :
    """

    """
    @dispatch

    def get_Item(self ,index:int)->IPrstGeomShape:
        """

        """
        
        GetDllLibXls().PrstGeomShapeCollection_get_Item.argtypes=[c_void_p ,c_int]
        GetDllLibXls().PrstGeomShapeCollection_get_Item.restype=c_void_p
        intPtr = GetDllLibXls().PrstGeomShapeCollection_get_Item(self.Ptr, index)
        ret = None if intPtr==None else XlsPrstGeomShape(intPtr)
        return ret


    @dispatch

    def get_Item(self ,name:str)->IPrstGeomShape:
        """

        """
        
        GetDllLibXls().PrstGeomShapeCollection_get_ItemN.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().PrstGeomShapeCollection_get_ItemN.restype=c_void_p
        intPtr = GetDllLibXls().PrstGeomShapeCollection_get_ItemN(self.Ptr, name)
        ret = None if intPtr==None else XlsPrstGeomShape(intPtr)
        return ret


    @dispatch

    def get_Item(self ,shapeType:PrstGeomShapeType)->List[IPrstGeomShape]:
        """

        """
        enumshapeType:c_int = shapeType.value

        GetDllLibXls().PrstGeomShapeCollection_get_ItemS.argtypes=[c_void_p ,c_int]
        GetDllLibXls().PrstGeomShapeCollection_get_ItemS.restype=IntPtrArray
        intPtrArray = GetDllLibXls().PrstGeomShapeCollection_get_ItemS(self.Ptr, enumshapeType)
        ret = GetObjVectorFromArray(intPtrArray, IPrstGeomShape)
        return ret



    def AddNotPrimitiveShape(self ,row:int,column:int,width:int,height:int)->'IGeomPathShape':
        """
    <summary>
        Add a NotPrimitive shape to prstgeomshape collection;
    </summary>
    <param name="row">shape's first row number in worksheet</param>
    <param name="column">shape's first column number in worksheet</param>
    <param name="width">shape's width, in unit of pixel.</param>
    <param name="height">shape's height, in unit of pixel.</param>
        """
        
        GetDllLibXls().PrstGeomShapeCollection_AddNotPrimitiveShape.argtypes=[c_void_p ,c_int,c_int,c_int,c_int]
        GetDllLibXls().PrstGeomShapeCollection_AddNotPrimitiveShape.restype=c_void_p
        intPtr = GetDllLibXls().PrstGeomShapeCollection_AddNotPrimitiveShape(self.Ptr, row,column,width,height)
        ret = None if intPtr==None else IGeomPathShape(intPtr)
        return ret



    def AddPrstGeomShape(self ,row:int,column:int,width:int,height:int,shapeType:'PrstGeomShapeType')->'IPrstGeomShape':
        """
    <summary>
        Add a preset shape to prstgeomshape collection;
    </summary>
    <param name="row">shape's first row number in worksheet</param>
    <param name="column">shape's first column number in worksheet</param>
    <param name="width">shape's width, in unit of pixel.</param>
    <param name="height">shape's height, in unit of pixel.</param>
    <param name="shapeType">shape's type</param>
    <returns></returns>
        """
        enumshapeType:c_int = shapeType.value

        GetDllLibXls().PrstGeomShapeCollection_AddPrstGeomShape.argtypes=[c_void_p ,c_int,c_int,c_int,c_int,c_int]
        GetDllLibXls().PrstGeomShapeCollection_AddPrstGeomShape.restype=c_void_p
        intPtr = GetDllLibXls().PrstGeomShapeCollection_AddPrstGeomShape(self.Ptr, row,column,width,height,enumshapeType)
        ret = None if intPtr==None else XlsPrstGeomShape(intPtr)
        return ret



    def AddCopy(self ,source:'IPrstGeomShape'):
        """

        """
        intPtrsource:c_void_p = source.Ptr

        GetDllLibXls().PrstGeomShapeCollection_AddCopy.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().PrstGeomShapeCollection_AddCopy(self.Ptr, intPtrsource)


    def Remove(self ,shape:'IShape'):
        """
    <summary>
        Remove a shape in collection;
    </summary>
    <param name="shape">the shape to remove</param>
        """
        intPtrshape:c_void_p = shape.Ptr

        GetDllLibXls().PrstGeomShapeCollection_Remove.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().PrstGeomShapeCollection_Remove(self.Ptr, intPtrshape)

    def Clear(self):
        """

        """
        GetDllLibXls().PrstGeomShapeCollection_Clear.argtypes=[c_void_p]
        GetDllLibXls().PrstGeomShapeCollection_Clear(self.Ptr)

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/PrstGeomShapeCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class PrstGeomShapeCollection (  CollectionBase[XlsPrstGeomShape], IPrstGeomShapes) :
    """

    """
    @dispatch

    def get_Item(self ,index:int)->IPrstGeomShape:
        """

        """
        
        GetDllLibXls().PrstGeomShapeCollection_get_Item.argtypes=[c_void_p ,c_int]
        GetDllLibXls().PrstGeomShapeCollection_get_Item.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().PrstGeomShapeCollection_get_Item, self.Ptr, index)
        ret = None if intPtr==None else XlsPrstGeomShape(intPtr)
        return ret


    @dispatch

    def get_Item(self ,name:str)->IPrstGeomShape:
        """

        """
        
        GetDllLibXls().PrstGeomShapeCollection_get_ItemN.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().PrstGeomShapeCollection_get_ItemN.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().PrstGeomShapeCollection_get_ItemN, self.Ptr, name)
        ret = None if intPtr==None else XlsPrstGeomShape(intPtr)
        return ret


    @dispatch

    def get_Item(self ,shapeType:PrstGeomShapeType)->List[IPrstGeomShape]:
        """

        """
        enumshapeType:c_int = shapeType.value

        GetDllLibXls().PrstGeomShapeCollection_get_ItemS.argtypes=[c_void_p ,c_int]
        GetDllLibXls().PrstGeomShapeCollection_get_ItemS.restype=IntPtrArray
        intPtrArray = CallCFunction(GetDllLibXls().PrstGeomShapeCollection_get_ItemS, self.Ptr, enumshapeType)
        ret = GetObjVectorFromArray(intPtrArray, IPrstGeomShape)
        return ret



    def AddNotPrimitiveShape(self ,row:int,column:int,width:int,height:int)->'IGeomPathShape':
        """
    <summary>
        Add a NotPrimitive shape to prstgeomshape collection;
    </summary>
    <param name="row">shape's first row number in worksheet</param>
    <param name="column">shape's first column number in worksheet</param>
    <param name="width">shape's width, in unit of pixel.</param>
    <param name="height">shape's height, in unit of pixel.</param>
        """
        
        GetDllLibXls().PrstGeomShapeCollection_AddNotPrimitiveShape.argtypes=[c_void_p ,c_int,c_int,c_int,c_int]
        GetDllLibXls().PrstGeomShapeCollection_AddNotPrimitiveShape.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().PrstGeomShapeCollection_AddNotPrimitiveShape, self.Ptr, row,column,width,height)
        ret = None if intPtr==None else IGeomPathShape(intPtr)
        return ret



    def AddPrstGeomShape(self ,row:int,column:int,width:int,height:int,shapeType:'PrstGeomShapeType')->'IPrstGeomShape':
        """
    <summary>
        Add a preset shape to prstgeomshape collection;
    </summary>
    <param name="row">shape's first row number in worksheet</param>
    <param name="column">shape's first column number in worksheet</param>
    <param name="width">shape's width, in unit of pixel.</param>
    <param name="height">shape's height, in unit of pixel.</param>
    <param name="shapeType">shape's type</param>
    <returns></returns>
        """
        enumshapeType:c_int = shapeType.value

        GetDllLibXls().PrstGeomShapeCollection_AddPrstGeomShape.argtypes=[c_void_p ,c_int,c_int,c_int,c_int,c_int]
        GetDllLibXls().PrstGeomShapeCollection_AddPrstGeomShape.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().PrstGeomShapeCollection_AddPrstGeomShape, self.Ptr, row,column,width,height,enumshapeType)
        ret = None if intPtr==None else XlsPrstGeomShape(intPtr)
        return ret



    def AddCopy(self ,source:'IPrstGeomShape'):
        """

        """
        intPtrsource:c_void_p = source.Ptr

        GetDllLibXls().PrstGeomShapeCollection_AddCopy.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibXls().PrstGeomShapeCollection_AddCopy, self.Ptr, intPtrsource)


    def Remove(self ,shape:'IShape'):
        """
    <summary>
        Remove a shape in collection;
    </summary>
    <param name="shape">the shape to remove</param>
        """
        intPtrshape:c_void_p = shape.Ptr

        GetDllLibXls().PrstGeomShapeCollection_Remove.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibXls().PrstGeomShapeCollection_Remove, self.Ptr, intPtrshape)

    def Clear(self):
        """

        """
        GetDllLibXls().PrstGeomShapeCollection_Clear.argtypes=[c_void_p]
        CallCFunction(GetDllLibXls().PrstGeomShapeCollection_Clear, self.Ptr)
